# 动手学习 Python

![repo size](https://img.shields.io/github/repo-size/sanstylex.github.io.svg)
[![PyPI][pypi-badge]][pypi-link]
[![GitHub issues][issue-badge]][issue-link]
[![GitHub forks][fork-badge]][fork-link]
[![GitHub stars][star-badge]][star-link]
[![GitHub license][license-badge]][license-link]
[![contributors][contributor-badge]][contributor-link]
[![watcher][watcher-badge]][watcher-link]
[![Binder][binder-badge]][binder-link]
[![Downloads][download-badge]][download-link]
[![Documentation Status][status-badge]][status-link]
[![PyPI - Downloads][install-badge]][install-link]

学无止境！

[pypi-badge]: https://img.shields.io/pypi/v/d2py.svg
[pypi-link]: https://pypi.org/project/d2py/
[issue-badge]: https://img.shields.io/github/issues/sanstylex.github.io
[issue-link]: https://github.com/sanstylex.github.io/issues
[fork-badge]: https://img.shields.io/github/forks/sanstylex.github.io
[fork-link]: https://github.com/sanstylex.github.io/network
[star-badge]: https://img.shields.io/github/stars/sanstylex.github.io
[star-link]: https://github.com/sanstylex.github.io/stargazers
[license-badge]: https://img.shields.io/github/license/sanstylex.github.io
[license-link]: https://github.com/sanstylex.github.io/LICENSE
[contributor-badge]: https://img.shields.io/github/contributors/sanstylex.github.io
[contributor-link]: https://github.com/sanstylex.github.io/contributors
[watcher-badge]: https://img.shields.io/github/watchers/sanstylex.github.io
[watcher-link]: https://github.com/sanstylex.github.io/watchers
[binder-badge]: https://mybinder.org/badge_logo.svg
[binder-link]: https://mybinder.org/v2/gh/sanstylex.github.io/main
[install-badge]: https://img.shields.io/pypi/dw/d2py?label=pypi%20installs
[install-link]: https://pypistats.org/packages/d2py
[status-badge]: https://readthedocs.org/projects/d2py/badge/?version=latest
[status-link]: https://d2py.readthedocs.io/zh/latest/?badge=latest
[download-badge]: https://pepy.tech/badge/d2py
[download-link]: https://pepy.tech/project/d2py

## PyPI

支持 PyPI：

```sh
pip install d2py
```

## 文档模板

优质文档模板：

- [xbook](https://xinetzone.github.io/xbook/index.html)
